---
title: "Aave BGD Phase 4"
author: "BGD Labs (@bgdlabs)"
discussions: "https://governance.aave.com/t/aave-bored-ghosts-developing-phase-4/19484"
snapshot: "https://snapshot.box/#/s:aave.eth/proposal/0x2dfb5a6e770bf7a34ddb5ab05560c24a169c63f84e9e8d373767a5b072f1f21d"
---

## Simple Summary

Proposal for an engagement of development and security services between the Aave DAO and BGD Labs, from 1st October 2024 until 1st April 2025.

## Motivation

For the last two and a half years, BGD Labs has been a service provider of the Aave DAO, contributing with multiple developments, technical maintenance, and security coordination tasks.

The motivation/goal of this new engagement is:

- Keep the stability and trust in the Aave technology.
- Innovate responsibly on production systems.
- Support all other non-tech contributors to the DAO, accelerating progress.

In summary, the same as before, but always striving for better.

## Specification

A full description of the scope can be found on the Aave Governance Forum [HERE](https://governance.aave.com/t/aave-bored-ghosts-developing-phase-4/19484#p-49320-aave-bgd-phase-iv-continuous-scope-4) or on the pre-approval on ARFC (Aave Request For Comments) [HERE](https://snapshot.box/#/s:aave.eth/proposal/0x2dfb5a6e770bf7a34ddb5ab05560c24a169c63f84e9e8d373767a5b072f1f21d).

In terms of implementation, this proposal sets up the payment schedule defined:

- From the Aave DAO's treasury (Collector smart contract), an upfront transfer for a value of 1'150'000 aUSDC (v3 Ethereum), 50% of the stablecoins budget.
- From the Aave DAO AAVE Ecosystem Reserve, an upfront transfer for a value of 2'500 AAVE tokens, 50% of the tokens budget.
- From the Aave DAO's treasury, the creation of a payment stream for a value of 1'150'000 aUSDC (v3 Ethereum), from the execution time of this proposal until 1st April 2025, completing the 6-month duration, for the other 50% of the stablecoins budget.
- From the Aave DAO AAVE Ecosystem Reserve, the creation of a payment stream for a value of 2'500 AAVE tokens, from the execution time of this proposal until 1st April 2025, completing the 6-month duration, for the other 50% of the tokens budget.

**The approval of this proposal by Aave governance acts as a binding agreement between the Aave DAO and BGD Labs**. Detailed terms of service can be found [HERE](https://bgdlabs.com/aave-dao-tos).

## References

- Implementation: [AaveV3Ethereum](https://github.com/bgd-labs/aave-proposals-v3/blob/e4ab6eb39d25f4e2ac3469e1a7cac0f4b294d0e1/src/20241025_AaveV3Ethereum_AaveBGDPhase4/AaveV3Ethereum_AaveBGDPhase4_20241025.sol)
- Tests: [AaveV3Ethereum](https://github.com/bgd-labs/aave-proposals-v3/blob/e4ab6eb39d25f4e2ac3469e1a7cac0f4b294d0e1/src/20241025_AaveV3Ethereum_AaveBGDPhase4/AaveV3Ethereum_AaveBGDPhase4_20241025.t.sol)
- [Snapshot](https://snapshot.box/#/s:aave.eth/proposal/0x2dfb5a6e770bf7a34ddb5ab05560c24a169c63f84e9e8d373767a5b072f1f21d)
- [Discussion](https://governance.aave.com/t/aave-bored-ghosts-developing-phase-4/19484)

## Copyright

Copyright and related rights waived via [CC0](https://creativecommons.org/publicdomain/zero/1.0/).
